@@ -8,7 +8,7 @@ from iterable_tompy import first, indices_around_index
 from py_cdll import CDLL
 
 from .exceptions import AngleInitValueError, ValueIsNotAnAngleError, AngleOptionsNotInExpectedRangeError, \
-    WrongValueAmountError
+    WrongValueAmountError, NoAngleLeftInSubsetToMatchError
 
 Numeric: TypeAlias = Union[sp.Expr, float, int, Fraction, Decimal]
 
@@ -303,31 +303,47 @@ def required_and_disallowed_corner_angles(location_angles: list[frozenset[Angle]
 
 
 def is_angle_combo_match_angles_subset(angle_combination: tuple[Angle, ...],
-                                       angles: tuple[Angle, ...],
-                                       subset_index: int) -> bool:
-    indices_around_angle: list[int] = indices_around_index(index=subset_index, collection=angles)
+                                       angle_subset: tuple[Angle, ...],
+                                       subset_index: int
+                                       ) -> bool:
+    """
+    Is this ordered list of angles,
+    present from the beginning of the Angles surrounding a selected index
+    in the subset of Angles belonging to a shape?
+    """
 
-    angles_around_angle: list[Angle] = [angles[index] for index in indices_around_angle]
+    if len(angle_combination) < len(angle_subset):
+        indices_around_angle: list[int] = indices_around_index(index=subset_index, collection=angle_subset)
 
-    is_all_angles_matching: bool = all((angle_from_combination == angle_from_angles
-                                        for angle_from_combination, angle_from_angles in
-                                        zip(angle_combination, angles_around_angle)))
+        angles_around_angle: list[Angle] = [angle_subset[index] for index in indices_around_angle]
+
+        is_all_angles_matching: bool = all((angle_from_combination == angle_from_angles
+                                            for angle_from_combination, angle_from_angles in
+                                            zip(angle_combination, angles_around_angle)))
+    else:
+        raise NoAngleLeftInSubsetToMatchError(f"{angle_combination} has so many items that {angle_subset} "
+                                              f"does not have any items remaining to match with.")
 
     return is_all_angles_matching
 
 
 def matching_angle_options_in_angles_subset(angle_combination: tuple[Angle, ...],
-                                            angles: tuple[Angle, ...],
-                                            subset_amount: int) -> set[Angle]:
+                                            angle_subset: tuple[Angle, ...],
+                                            subset_amount: int
+                                            ) -> set[Angle]:
     angle_options: set[Angle] = set()
 
     for subset_index in range(subset_amount):
-        is_all_angles_matching: bool = is_angle_combo_match_angles_subset(angle_combination=angle_combination,
-                                                                          angles=angles,
-                                                                          subset_index=subset_index)
+        """Trying each possibility in the subset amount, as the position we are finding solution for."""
+        try:
+            is_all_angles_matching: bool = is_angle_combo_match_angles_subset(angle_combination=angle_combination,
+                                                                              angle_subset=angle_subset,
+                                                                              subset_index=subset_index)
+        except NoAngleLeftInSubsetToMatchError as _:
+            is_all_angles_matching: bool = False
 
         if is_all_angles_matching:
-            angle_option: Angle = angles[subset_index - 1]
+            angle_option: Angle = angle_subset[subset_index]
             angle_options.add(angle_option)
             break
 
@@ -335,13 +351,14 @@ def matching_angle_options_in_angles_subset(angle_combination: tuple[Angle, ...]
 
 
 def options_from_combinations_and_subsets(angle_combinations: set[tuple[Angle, ...]],
-                                          angle_subsets: dict[tuple[Angle, ...], int]) -> set[Angle]:
+                                          angle_subsets: dict[tuple[Angle, ...], int]
+                                          ) -> set[Angle]:
     angle_options: set[Angle] = set()
 
     for angle_combination in angle_combinations:
-        for angles, subset_amount in angle_subsets.items():
+        for angle_subset, subset_amount in angle_subsets.items():
             angle_options |= matching_angle_options_in_angles_subset(angle_combination=angle_combination,
-                                                                     angles=angles,
+                                                                     angle_subset=angle_subset,
                                                                      subset_amount=subset_amount)
 
     return angle_options
@@ -350,10 +367,18 @@ def options_from_combinations_and_subsets(angle_combinations: set[tuple[Angle, .
 def merge_angle_combinations(combinations: set[tuple[Angle, ...]],
                              combination: set[tuple[Angle, ...]]
                              ) -> set[tuple[Angle, ...]]:
+    """
+    Adding both orders of combination variations is done as a substitute for the much harder problem of
+    analyzing how the Angles are ordered in relation to other Angles in the sequence.
+    """
+
+    new_combinations: set[tuple[Angle, ...]] = set()
+
+    for old_combination in combinations:
+        for new_combination in combination:
+            new_combinations.add((old_combination + new_combination))
+            new_combinations.add((new_combination + old_combination))
 
-    new_combinations: set[tuple[Angle, ...]] = {new_combination + old_combination
-                                                for new_combination in combination
-                                                for old_combination in combinations}
     return new_combinations
 
 
