@@ -16,3 +16,7 @@ class AngleOptionsNotInExpectedRangeError(BaseAngleException):
 
 class WrongValueAmountError(BaseAngleException):
     """Unexpected amount of values."""
+
+
+class NoAngleLeftInSubsetToMatchError(BaseAngleException):
+    """Too few Angles in subset compared with Angles in combination."""
